@@ -10,11 +10,12 @@ import re
 import uuid
 from typing import TYPE_CHECKING
 
+from fast_tracker.utils import functions
+
 if TYPE_CHECKING:
     from typing import List
 
 import fast_tracker
-from fast_tracker.loggings import logger
 
 RE_IGNORE_PATH = os.getenv("FastTracker_ReIgnorePath") or re.compile("^$")  # type: re.Pattern
 
@@ -33,6 +34,10 @@ tracker_version = fast_tracker.version
 enable = False  # type: bool
 # 环境编码
 env_code = "test"  # type: str
+# Debug开关
+debug = False
+# debug level
+debug_level = 0
 # 日志等级
 logging_level = "ERROR"  # type: str
 # 租户编码
@@ -46,7 +51,7 @@ product_code = ""  # type: str
 # 服务编码
 app_code = ""  # type: str
 # 上报地址
-collector_address = ""  # type: str
+collector_address = "127.0.0.1:5140"  # type: str
 # 缓冲区大小 默认1
 buffer_size = 1  # type: int
 # 上报超时时间 默认1（秒）
@@ -64,6 +69,8 @@ env_code_reader = {"ReaderType": "Cookie", "ReaderKey": "env_code"}
 # 前端Header
 carrier_header = {"TrackerName": "fast-tracker", "TraceIdName": "x-fast-trace-id"}
 disable_plugins = []  # type: List[str]
+# 配置文件路径
+config_file = ""
 ############################# fast_tracker默认配置信息结束 ###############################
 # 用户自定义user_code、tenant_code、env_code字段值
 custom_user_code = ""
@@ -75,12 +82,14 @@ def init(
     service: str = None, instance: str = None, collector: str = None, protocol_type: str = "udp", token: str = None
 ):
     # 先根据环境变量 FastTracker_ConfigPath 加载配置文件并赋值
+    global config_file
     config_file = os.environ.get("FastTracker_ConfigPath", None)
-    logger.debug("FAST: FastTracker_ConfigPath is %s " % config_file)
     from fast_tracker.fast_tracker_configer import FastTrackerConfiger
 
     if config_file:
         FastTrackerConfiger.load_configuration(config_file)
+    else:
+        print("FAST: 探针配置文件未指定")
 
     # 再根据环境变量加载配置
     FastTrackerConfiger.set_config_by_env()
@@ -119,6 +128,16 @@ def set_debug(cus_debug: bool = False):
     debug = cus_debug
 
 
+def set_debug_level(cus_debug_level: int = 0):
+    """
+    设置 debug_level 值
+    :param cus_debug_level:
+    :return:
+    """
+    global debug_level
+    debug_level = cus_debug_level
+
+
 def set_env_code(cus_env_code: str = ""):
     """
     设置env_code值
