@@ -200,6 +200,8 @@ class FastTracker:
             "CorrelationValueMaxLength": config.correlation_value_max_length,
             "TraceIgnorePath": config.trace_ignore_path,
             "Enable": config.enable,
+            "Debug": config.debug,
+            "DebugLevel": config.debug_level,
             "EnvCode": config.env_code,
             "TenantCode": config.tenant_code,
             "UserCode": config.user_code,
@@ -279,6 +281,8 @@ class FastTracker:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.stop()
 
+    log_level = {"NOTSET": 0, "DEBUG": 10, "INFO": 20, "WARNING": 30, "ERROR": 40, "CRITICAL": 50}
+
     def debug(self, msg: str = ""):
         self.__logging(msg, err_type="DEBUG")
 
@@ -299,6 +303,10 @@ class FastTracker:
 
     def __logging(self, msg: str = "", err_type: str = ""):
         try:
+            config_log_type = FastTracker.log_level.get(config.logging_level)
+            cus_log_type = FastTracker.log_level.get(err_type)
+            if config_log_type > cus_log_type:
+                return False
             if "fast_log" in config.disable_plugins:
                 raise RuntimeError("已在配置Event-Components-Logging中关闭此项")
             context = get_context()
@@ -307,6 +315,6 @@ class FastTracker:
             with context.new_local_span(op="Logging") as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
-                span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(msg, err_type="DEBUG"))]))
+                span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(msg, err_type=err_type))]))
         except Exception as e:
             raise e
